==> lowcode-react-simulator-renderer-1.2.7.tgz: package/es/renderer-view.js <==
import _extends from "@babel/runtime/helpers/extends";
import _inheritsLoose from "@babel/runtime/helpers/inheritsLoose";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
var _class, _class2, _class3;
var _excluded = ["_leaf"],
  _excluded2 = ["__id"];
import { Fragment, Component, createElement } from 'react';
import { Router, Route, Switch } from 'react-router';
import cn from 'classnames';
import LowCodeRenderer from '@alilc/lowcode-react-renderer';
import { observer } from 'mobx-react';
import { getClosestNode, isFromVC, isReactComponent } from '@alilc/lowcode-utils';
import { GlobalEvent } from '@alilc/lowcode-types';
import { host } from './host';
import { isRendererDetached } from './utils/misc';
import './renderer.less';
import { createIntl } from './locale';

// patch cloneElement avoid lost keyProps
var originCloneElement = window.React.cloneElement;
window.React.cloneElement = function (child, _temp) {
  var _ref = _temp === void 0 ? {} : _temp,
    _leaf = _ref._leaf,
    props = _objectWithoutPropertiesLoose(_ref, _excluded);
  if (child.ref && props.ref) {
    var dRef = props.ref;
    var cRef = child.ref;
    props.ref = function (x) {
      if (cRef) {
        if (typeof cRef === 'function') {
          cRef(x);
        } else {
          try {
            cRef.current = x;
          } catch (e) {
            console.error(e);
          }
        }
      }
      if (dRef) {
        if (typeof dRef === 'function') {
          dRef(x);
        } else {
          try {
            dRef.current = x;
          } catch (e) {
            console.error(e);
          }
        }
      }
    };
  }
  for (var _len = arguments.length, rest = new Array(_len > 2 ? _len - 2 : 0), _key = 2; _key < _len; _key++) {
    rest[_key - 2] = arguments[_key];
  }
  return originCloneElement.apply(void 0, [child, props].concat(rest));
};
var SimulatorRendererView = /*#__PURE__*/function (_Component) {
  _inheritsLoose(SimulatorRendererView, _Component);
  function SimulatorRendererView() {
    return _Component.apply(this, arguments) || this;
  }
  var _proto = SimulatorRendererView.prototype;
  _proto.render = function render() {
    var rendererContainer = this.props.rendererContainer;
    return /*#__PURE__*/React.createElement(Router, {
      history: rendererContainer.history
    }, /*#__PURE__*/React.createElement(Layout, {
      rendererContainer: rendererContainer
    }, /*#__PURE__*/React.createElement(Routes, {
      rendererContainer: rendererContainer
    })));
  };
  return SimulatorRendererView;
}(Component);
export { SimulatorRendererView as default };
export var Routes = observer(_class = /*#__PURE__*/function (_Component2) {
  _inheritsLoose(Routes, _Component2);
  function Routes() {
    return _Component2.apply(this, arguments) || this;
  }
  var _proto2 = Routes.prototype;
  _proto2.render = function render() {
    var rendererContainer = this.props.rendererContainer;
    return /*#__PURE__*/React.createElement(Switch, null, rendererContainer.documentInstances.map(function (instance) {
      return /*#__PURE__*/React.createElement(Route, {
        path: instance.path,
        key: instance.id,
        render: function render(routeProps) {
          return /*#__PURE__*/React.createElement(Renderer, _extends({
            documentInstance: instance,
            rendererContainer: rendererContainer
          }, routeProps));
        }
      });
    }));
  };
  return Routes;
}(Component)) || _class;
function ucfirst(s) {
  return s.charAt(0).toUpperCase() + s.substring(1);
}
function getDeviceView(view, device, mode) {
  if (!view || typeof view === 'string') {
    return view;
  }

  // compatible vision Mobile | Preview
  device = ucfirst(device);
  if (device === 'Mobile' && view.hasOwnProperty(device)) {
    view = view[device];
  }
  mode = ucfirst(mode);
  if (mode === 'Preview' && view.hasOwnProperty(mode)) {
    view = view[mode];
  }
  return view;
}
var Layout = observer(_class2 = /*#__PURE__*/function (_Component3) {
  _inheritsLoose(Layout, _Component3);
  function Layout() {
    return _Component3.apply(this, arguments) || this;
  }
  var _proto3 = Layout.prototype;
  _proto3.render = function render() {
    var _this$props = this.props,
      rendererContainer = _this$props.rendererContainer,
      children = _this$props.children;
    var layout = rendererContainer.layout;
    if (layout) {
      var _Component4 = layout.Component,
        props = layout.props,
        componentName = layout.componentName;
      if (_Component4) {
        return /*#__PURE__*/React.createElement(_Component4, {
          key: "layout",
          props: props
        }, children);
      }
      if (componentName && rendererContainer.getComponent(componentName)) {
        return /*#__PURE__*/createElement(rendererContainer.getComponent(componentName), _extends({}, props, {
          rendererContainer: rendererContainer,
          key: 'layout'
        }), [children]);
      }
    }
    return /*#__PURE__*/React.createElement(Fragment, null, children);
  };
  return Layout;
}(Component)) || _class2;
var Renderer = observer(_class3 = /*#__PURE__*/function (_Component5) {
  _inheritsLoose(Renderer, _Component5);
  function Renderer() {
    var _this;
    for (var _len2 = arguments.length, args = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
      args[_key2] = arguments[_key2];
    }
    _this = _Component5.call.apply(_Component5, [this].concat(args)) || this;
    _this.startTime = null;
    _this.schemaChangedSymbol = false;
    _this.getSchemaChangedSymbol = function () {
      return _this.schemaChangedSymbol;
    };
    _this.setSchemaChangedSymbol = function (symbol) {
      _this.schemaChangedSymbol = symbol;
    };
    return _this;
  }
  var _proto4 = Renderer.prototype;
  _proto4.componentDidUpdate = function componentDidUpdate() {
    this.recordTime();
  };
  _proto4.recordTime = function recordTime() {
    if (this.startTime) {
      var _host$designer$curren, _host$designer$curren2, _host$designer$editor;
      var time = Date.now() - this.startTime;
      var nodeCount = (_host$designer$curren = host.designer.currentDocument) === null || _host$designer$curren === void 0 ? void 0 : (_host$designer$curren2 = _host$designer$curren.getNodeCount) === null || _host$designer$curren2 === void 0 ? void 0 : _host$designer$curren2.call(_host$designer$curren);
      (_host$designer$editor = host.designer.editor) === null || _host$designer$editor === void 0 ? void 0 : _host$designer$editor.eventBus.emit(GlobalEvent.Node.Rerender, {
        componentName: 'Renderer',
        type: 'All',
        time: time,
        nodeCount: nodeCount
      });
    }
  };
  _proto4.componentDidMount = function componentDidMount() {
    this.recordTime();
  };
  _proto4.render = function render() {
    var _container$context, _container$context$ut, _container$context$ut2;
    var _this$props2 = this.props,
      documentInstance = _this$props2.documentInstance,
      renderer = _this$props2.rendererContainer;
    var container = documentInstance.container,
      document = documentInstance.document;
    var designMode = container.designMode,
      device = container.device,
      locale = container.locale;
    var messages = ((_container$context = container.context) === null || _container$context === void 0 ? void 0 : (_container$context$ut = _container$context.utils) === null || _container$context$ut === void 0 ? void 0 : (_container$context$ut2 = _container$context$ut.i18n) === null || _container$context$ut2 === void 0 ? void 0 : _container$context$ut2.messages) || {};
    this.startTime = Date.now();
    this.schemaChangedSymbol = false;
    if (!container.autoRender || isRendererDetached()) {
      return null;
    }
    var _createIntl = createIntl(locale),
      intl = _createIntl.intl;
    return /*#__PURE__*/React.createElement(LowCodeRenderer, {
      locale: locale,
      messages: messages,
      schema: documentInstance.schema,
      components: container.components,
      appHelper: container.context,
      designMode: designMode,
      device: device,
      documentId: document.id,
      suspended: renderer.suspended,
      self: renderer.scope,
      getSchemaChangedSymbol: this.getSchemaChangedSymbol,
      setSchemaChangedSymbol: this.setSchemaChangedSymbol,
      getNode: function getNode(id) {
        return documentInstance.getNode(id);
      },
      rendererName: "PageRenderer",
      thisRequiredInJSE: host.thisRequiredInJSE,
      notFoundComponent: host.notFoundComponent,
      faultComponent: host.faultComponent,
      faultComponentMap: host.faultComponentMap,
      customCreateElement: function customCreateElement(Component, props, children) {
        var __id = props.__id,
          viewProps = _objectWithoutPropertiesLoose(props, _excluded2);
        viewProps.componentId = __id;
        var leaf = documentInstance.getNode(__id);
        if (isFromVC(leaf === null || leaf === void 0 ? void 0 : leaf.componentMeta)) {
          viewProps._leaf = leaf.internalToShellNode();
        }
        viewProps._componentName = leaf === null || leaf === void 0 ? void 0 : leaf.componentName;
        // 如果是容器 && 无children && 高宽为空 增加一个占位容器，方便拖动
        if (!viewProps.dataSource && leaf !== null && leaf !== void 0 && leaf.isContainer() && (children == null || Array.isArray(children) && !children.length) && (!viewProps.style || Object.keys(viewProps.style).length === 0)) {
          var defaultPlaceholder = intl('Drag and drop components or templates here');
          var lockedNode = getClosestNode(leaf, function (node) {
            var _node$getExtraProp;
            return (node === null || node === void 0 ? void 0 : (_node$getExtraProp = node.getExtraProp('isLocked')) === null || _node$getExtraProp === void 0 ? void 0 : _node$getExtraProp.getValue()) === true;
          });
          if (lockedNode) {
            defaultPlaceholder = intl('Locked elements and child elements cannot be edited');
          }
          children = /*#__PURE__*/React.createElement("div", {
            className: cn('lc-container-placeholder', {
              'lc-container-locked': !!lockedNode
            }),
            style: viewProps.placeholderStyle
          }, viewProps.placeholder || defaultPlaceholder);
        }
        if (viewProps._componentName === 'a') {
          delete viewProps.href;
        }
        // FIXME: 渲染仍有问题
        if (viewProps._componentName === 'Menu') {
          Object.assign(viewProps, {
            _componentName: 'Menu',
            className: '_css_pesudo_menu_kbrzyh0f',
            context: {
              VE: window.VisualEngine
            },
            direction: undefined,
            events: {
              ignored: true
            },
            fieldId: 'menu_kbrzyh0f',
            footer: '',
            header: '',
            mode: 'inline',
            onItemClick: {
              ignored: true
            },
            onSelect: {
              ignored: true
            },
            popupAlign: 'follow',
            selectMode: false,
            triggerType: 'click'
          });
        }
        if (!isReactComponent(Component)) {
          console.error(viewProps._componentName + " is not a react component!");
          return null;
        }
        return /*#__PURE__*/createElement(getDeviceView(Component, device, designMode), viewProps, leaf !== null && leaf !== void 0 && leaf.isContainer() ? children == null ? [] : Array.isArray(children) ? children : [children] : children);
      },
      __host: host,
      __container: container,
      onCompGetRef: function onCompGetRef(schema, ref) {
        documentInstance.mountInstance(schema.id, ref);
      },
      enableStrictNotFoundMode: host.enableStrictNotFoundMode
    });
  };
  return Renderer;
}(Component)) || _class3;

==> lowcode-react-simulator-renderer-1.2.10.tgz: package/es/renderer-view.js <==
import _extends from "@babel/runtime/helpers/extends";
import _inheritsLoose from "@babel/runtime/helpers/inheritsLoose";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
var _class, _class2, _class3;
var _excluded = ["_leaf"],
  _excluded2 = ["__id"];
import { Fragment, Component, createElement } from 'react';
import { Router, Route, Switch } from 'react-router';
import cn from 'classnames';
import LowCodeRenderer from '@bitwebsvc/lowcode-react-renderer';
import { observer } from 'mobx-react';
import { getClosestNode, isFromVC, isReactComponent } from '@bitwebsvc/lowcode-utils';
import { GlobalEvent } from '@bitwebsvc/lowcode-types';
import { host } from './host';
import { isRendererDetached } from './utils/misc';
import './renderer.less';
import { createIntl } from './locale';

// patch cloneElement avoid lost keyProps
var originCloneElement = window.React.cloneElement;
window.React.cloneElement = function (child, _temp) {
  var _ref = _temp === void 0 ? {} : _temp,
    _leaf = _ref._leaf,
    props = _objectWithoutPropertiesLoose(_ref, _excluded);
  if (child.ref && props.ref) {
    var dRef = props.ref;
    var cRef = child.ref;
    props.ref = function (x) {
      if (cRef) {
        if (typeof cRef === 'function') {
          cRef(x);
        } else {
          try {
            cRef.current = x;
          } catch (e) {
            console.error(e);
          }
        }
      }
      if (dRef) {
        if (typeof dRef === 'function') {
          dRef(x);
        } else {
          try {
            dRef.current = x;
          } catch (e) {
            console.error(e);
          }
        }
      }
    };
  }
  for (var _len = arguments.length, rest = new Array(_len > 2 ? _len - 2 : 0), _key = 2; _key < _len; _key++) {
    rest[_key - 2] = arguments[_key];
  }
  return originCloneElement.apply(void 0, [child, props].concat(rest));
};
var SimulatorRendererView = /*#__PURE__*/function (_Component) {
  _inheritsLoose(SimulatorRendererView, _Component);
  function SimulatorRendererView() {
    return _Component.apply(this, arguments) || this;
  }
  var _proto = SimulatorRendererView.prototype;
  _proto.render = function render() {
    var rendererContainer = this.props.rendererContainer;
    return /*#__PURE__*/React.createElement(Router, {
      history: rendererContainer.history
    }, /*#__PURE__*/React.createElement(Layout, {
      rendererContainer: rendererContainer
    }, /*#__PURE__*/React.createElement(Routes, {
      rendererContainer: rendererContainer
    })));
  };
  return SimulatorRendererView;
}(Component);
export { SimulatorRendererView as default };
export var Routes = observer(_class = /*#__PURE__*/function (_Component2) {
  _inheritsLoose(Routes, _Component2);
  function Routes() {
    return _Component2.apply(this, arguments) || this;
  }
  var _proto2 = Routes.prototype;
  _proto2.render = function render() {
    var rendererContainer = this.props.rendererContainer;
    return /*#__PURE__*/React.createElement(Switch, null, rendererContainer.documentInstances.map(function (instance) {
      return /*#__PURE__*/React.createElement(Route, {
        path: instance.path,
        key: instance.id,
        render: function render(routeProps) {
          return /*#__PURE__*/React.createElement(Renderer, _extends({
            documentInstance: instance,
            rendererContainer: rendererContainer
          }, routeProps));
        }
      });
    }));
  };
  return Routes;
}(Component)) || _class;
function ucfirst(s) {
  return s.charAt(0).toUpperCase() + s.substring(1);
}
function getDeviceView(view, device, mode) {
  if (!view || typeof view === 'string') {
    return view;
  }

  // compatible vision Mobile | Preview
  device = ucfirst(device);
  if (device === 'Mobile' && view.hasOwnProperty(device)) {
    view = view[device];
  }
  mode = ucfirst(mode);
  if (mode === 'Preview' && view.hasOwnProperty(mode)) {
    view = view[mode];
  }
  return view;
}
var Layout = observer(_class2 = /*#__PURE__*/function (_Component3) {
  _inheritsLoose(Layout, _Component3);
  function Layout() {
    return _Component3.apply(this, arguments) || this;
  }
  var _proto3 = Layout.prototype;
  _proto3.render = function render() {
    var _this$props = this.props,
      rendererContainer = _this$props.rendererContainer,
      children = _this$props.children;
    var layout = rendererContainer.layout;
    if (layout) {
      var _Component4 = layout.Component,
        props = layout.props,
        componentName = layout.componentName;
      if (_Component4) {
        return /*#__PURE__*/React.createElement(_Component4, {
          key: "layout",
          props: props
        }, children);
      }
      if (componentName && rendererContainer.getComponent(componentName)) {
        return /*#__PURE__*/createElement(rendererContainer.getComponent(componentName), _extends({}, props, {
          rendererContainer: rendererContainer,
          key: 'layout'
        }), [children]);
      }
    }
    return /*#__PURE__*/React.createElement(Fragment, null, children);
  };
  return Layout;
}(Component)) || _class2;
var Renderer = observer(_class3 = /*#__PURE__*/function (_Component5) {
  _inheritsLoose(Renderer, _Component5);
  function Renderer() {
    var _this;
    for (var _len2 = arguments.length, args = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
      args[_key2] = arguments[_key2];
    }
    _this = _Component5.call.apply(_Component5, [this].concat(args)) || this;
    _this.startTime = null;
    _this.schemaChangedSymbol = false;
    _this.getSchemaChangedSymbol = function () {
      return _this.schemaChangedSymbol;
    };
    _this.setSchemaChangedSymbol = function (symbol) {
      _this.schemaChangedSymbol = symbol;
    };
    return _this;
  }
  var _proto4 = Renderer.prototype;
  _proto4.componentDidUpdate = function componentDidUpdate() {
    this.recordTime();
  };
  _proto4.recordTime = function recordTime() {
    if (this.startTime) {
      var _host$designer$curren, _host$designer$curren2, _host$designer$editor;
      var time = Date.now() - this.startTime;
      var nodeCount = (_host$designer$curren = host.designer.currentDocument) === null || _host$designer$curren === void 0 ? void 0 : (_host$designer$curren2 = _host$designer$curren.getNodeCount) === null || _host$designer$curren2 === void 0 ? void 0 : _host$designer$curren2.call(_host$designer$curren);
      (_host$designer$editor = host.designer.editor) === null || _host$designer$editor === void 0 ? void 0 : _host$designer$editor.eventBus.emit(GlobalEvent.Node.Rerender, {
        componentName: 'Renderer',
        type: 'All',
        time: time,
        nodeCount: nodeCount
      });
    }
  };
  _proto4.componentDidMount = function componentDidMount() {
    this.recordTime();
  };
  _proto4.render = function render() {
    var _container$context, _container$context$ut, _container$context$ut2;
    var _this$props2 = this.props,
      documentInstance = _this$props2.documentInstance,
      renderer = _this$props2.rendererContainer;
    var container = documentInstance.container,
      document = documentInstance.document;
    var designMode = container.designMode,
      device = container.device,
      locale = container.locale;
    var messages = ((_container$context = container.context) === null || _container$context === void 0 ? void 0 : (_container$context$ut = _container$context.utils) === null || _container$context$ut === void 0 ? void 0 : (_container$context$ut2 = _container$context$ut.i18n) === null || _container$context$ut2 === void 0 ? void 0 : _container$context$ut2.messages) || {};
    this.startTime = Date.now();
    this.schemaChangedSymbol = false;
    if (!container.autoRender || isRendererDetached()) {
      return null;
    }
    var _createIntl = createIntl(locale),
      intl = _createIntl.intl;
    return /*#__PURE__*/React.createElement(LowCodeRenderer, {
      locale: locale,
      messages: messages,
      schema: documentInstance.schema,
      components: container.components,
      appHelper: container.context,
      designMode: designMode,
      device: device,
      documentId: document.id,
      suspended: renderer.suspended,
      self: renderer.scope,
      getSchemaChangedSymbol: this.getSchemaChangedSymbol,
      setSchemaChangedSymbol: this.setSchemaChangedSymbol,
      getNode: function getNode(id) {
        return documentInstance.getNode(id);
      },
      rendererName: "PageRenderer",
      thisRequiredInJSE: host.thisRequiredInJSE,
      notFoundComponent: host.notFoundComponent,
      faultComponent: host.faultComponent,
      faultComponentMap: host.faultComponentMap,
      customCreateElement: function customCreateElement(Component, props, children) {
        var __id = props.__id,
          viewProps = _objectWithoutPropertiesLoose(props, _excluded2);
        viewProps.componentId = __id;
        var leaf = documentInstance.getNode(__id);
        if (isFromVC(leaf === null || leaf === void 0 ? void 0 : leaf.componentMeta)) {
          viewProps._leaf = leaf.internalToShellNode();
        }
        viewProps._componentName = leaf === null || leaf === void 0 ? void 0 : leaf.componentName;
        // 如果是容器 && 无children && 高宽为空 增加一个占位容器，方便拖动
        if (!viewProps.dataSource && leaf !== null && leaf !== void 0 && leaf.isContainer() && (children == null || Array.isArray(children) && !children.length) && (!viewProps.style || Object.keys(viewProps.style).length === 0)) {
          var defaultPlaceholder = intl('Drag and drop components or templates here');
          var lockedNode = getClosestNode(leaf, function (node) {
            var _node$getExtraProp;
            return (node === null || node === void 0 ? void 0 : (_node$getExtraProp = node.getExtraProp('isLocked')) === null || _node$getExtraProp === void 0 ? void 0 : _node$getExtraProp.getValue()) === true;
          });
          if (lockedNode) {
            defaultPlaceholder = intl('Locked elements and child elements cannot be edited');
          }
          children = /*#__PURE__*/React.createElement("div", {
            className: cn('lc-container-placeholder', {
              'lc-container-locked': !!lockedNode
            }),
            style: viewProps.placeholderStyle
          }, viewProps.placeholder || defaultPlaceholder);
        }
        if (viewProps._componentName === 'a') {
          delete viewProps.href;
        }
        // FIXME: 渲染仍有问题
        if (viewProps._componentName === 'Menu') {
          Object.assign(viewProps, {
            _componentName: 'Menu',
            className: '_css_pesudo_menu_kbrzyh0f',
            context: {
              VE: window.VisualEngine
            },
            direction: undefined,
            events: {
              ignored: true
            },
            fieldId: 'menu_kbrzyh0f',
            footer: '',
            header: '',
            mode: 'inline',
            onItemClick: {
              ignored: true
            },
            onSelect: {
              ignored: true
            },
            popupAlign: 'follow',
            selectMode: false,
            triggerType: 'click'
          });
        }
        if (!isReactComponent(Component)) {
          console.error(viewProps._componentName + " is not a react component!");
          return null;
        }
        return /*#__PURE__*/createElement(getDeviceView(Component, device, designMode), viewProps, leaf !== null && leaf !== void 0 && leaf.isContainer() ? children == null ? [] : Array.isArray(children) ? children : [children] : children);
      },
      __host: host,
      __container: container,
      onCompGetRef: function onCompGetRef(schema, ref) {
        documentInstance.mountInstance(schema.id, ref);
      },
      enableStrictNotFoundMode: host.enableStrictNotFoundMode
    });
  };
  return Renderer;
}(Component)) || _class3;
